==> gnuradio_3.6.5.1.orig.tar.gz: gnuradio-3.6.5.1/gr-blocks/lib/repeat_impl.cc <==
/* -*- c++ -*- */
/*
 * Copyright 2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "repeat_impl.h"
#include <gr_io_signature.h>

namespace gr {
  namespace blocks {

    repeat::sptr repeat::make(size_t itemsize, int interp)
    {
      return gnuradio::get_initial_sptr(new repeat_impl(itemsize, interp));
    }

    repeat_impl::repeat_impl(size_t itemsize, int interp)
      : gr_sync_interpolator("repeat",
			     gr_make_io_signature (1, 1, itemsize),
			     gr_make_io_signature (1, 1, itemsize),
			     interp),
	d_itemsize(itemsize),
	d_interp(interp)
    {
    }

    int
    repeat_impl::work(int noutput_items,
		      gr_vector_const_void_star &input_items,
		      gr_vector_void_star &output_items)
    {
      const char *in = (const char *) input_items[0];
      char *out = (char *)output_items[0];
      
      for (int i = 0; i < noutput_items/d_interp; i++) {
	for (int j = 0; j < d_interp; j++) {
	  memcpy(out, in, d_itemsize);
	  out += d_itemsize;
	}
	
	in += d_itemsize;
      }
      
      return noutput_items;
    }

  } /* namespace blocks */
} /* namespace gr */

==> gnuradio_3.7.2.1.orig.tar.gz: gnuradio-3.7.2.1/gr-blocks/lib/repeat_impl.cc <==
/* -*- c++ -*- */
/*
 * Copyright 2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "repeat_impl.h"
#include <gnuradio/io_signature.h>

namespace gr {
  namespace blocks {

    repeat::sptr repeat::make(size_t itemsize, int interp)
    {
      return gnuradio::get_initial_sptr(new repeat_impl(itemsize, interp));
    }

    repeat_impl::repeat_impl(size_t itemsize, int interp)
      : sync_interpolator("repeat",
			     io_signature::make (1, 1, itemsize),
			     io_signature::make (1, 1, itemsize),
			     interp),
	d_itemsize(itemsize),
	d_interp(interp)
    {
    }

    int
    repeat_impl::work(int noutput_items,
		      gr_vector_const_void_star &input_items,
		      gr_vector_void_star &output_items)
    {
      const char *in = (const char *) input_items[0];
      char *out = (char *)output_items[0];
      
      for (int i = 0; i < noutput_items/d_interp; i++) {
	for (int j = 0; j < d_interp; j++) {
	  memcpy(out, in, d_itemsize);
	  out += d_itemsize;
	}
	
	in += d_itemsize;
      }
      
      return noutput_items;
    }

  } /* namespace blocks */
} /* namespace gr */
